@@ -32,8 +32,8 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x031103
-pyqt_version_str = "3.17.3"
+pyqt_version = 0x031104
+pyqt_version_str = "3.17.4"
 
 sip_min_version = 0x040600
 
@@ -779,6 +779,9 @@ def get_feature_flags():
         flags.extend(string.split(line))
         line = ff.readline()
 
+    if sipcfg.sip_version >= 0x040702:
+        flags.extend(['-x', 'Qt_SIP_PRE_4_7_2'])
+
     return flags
 
 
